Function rodalies_cli::config::cli::init_cli
source · pub fn init_cli() -> ArgMatchesExpand description
Configures the CLI behaviour, reads the arguments and returns and returns a container of matches.
pub fn init_cli() -> ArgMatchesConfigures the CLI behaviour, reads the arguments and returns and returns a container of matches.